% script to illustrate basic operations with a model

% housekeeping
clear all
close all
clc

% read the model
m = model('first_model.model','linear',true);
m
% solve the model
m = solve(m);
% find steady-state
m = sstate(m);
m
get(m,'sstate')

%% Simulate simple shock
% simulate with the model
db = sstatedb(m,qq(2015,1):qq(2016,4));
db.shock_dl_cpi(qq(2017,1)) = 2;

s = simulate(m, db, qq(2015,4):qq(2020,1),'anticipate',false);

% plot results
figure();
subplot(221);
  plot(s.dl_cpi,'linewidth',3);
  title('Inflace, % QoQ');
  grid
subplot(222);
  plot(s.l_y_gap,'linewidth',3);
  title('Output Gap, %');
  grid
subplot(223);
  plot(s.i,'linewidth',3);
  title('Nominal interest rate, % p.a.');
  grid
subplot(224);
  plot(s.r,'linewidth',3);
  title('Real interest rate, % p.a.');
  grid

% what about the overshooting? How can we change that?

  
%% Multiple parameterization
m(1:2) = m; 
% m. = [0. 0.];

m = solve(m);
m = sstate(m);

s2 = simulate(m, db, qq(2015,4):qq(2020,1),'anticipate',false);

% plot results
figure();
subplot(221);
  plot(s2.dl_cpi,'linewidth',3);
  title('Inflace, % QoQ');
  grid
subplot(222);
  plot(s2.l_y_gap,'linewidth',3);
  title('Output Gap, %');
  grid
subplot(223);
  plot(s2.i,'linewidth',3);
  title('Nominal interest rate, % p.a.');
  grid
subplot(224);
  plot(s2.r,'linewidth',3);
  title('Real interest rate, % p.a.');
  grid
